@@ -3,6 +3,7 @@ from iot_rdb.util import IotRedisBasic
 from iot_rdb.util import IotRedisPublisher
 from iot_rdb.util import IotRedisSubscriber
 from iot_rdb.util import IotRedisPubSub
+__version__ = "0.1.4"
 
 
 class IotRedisCommon:
@@ -18,16 +19,16 @@ class IotRedisCommon:
     }
 
     Channels publishing now:
-        - CONTROLLER : control_input
+        - CONTROLLER : control_input, init_vars
         - OPCUA: raw_outputs, perturbations, inputs
-        - AUTOENCODER: filtered_outputs
+        - AUTOENCODER: filtered_outputs, init_vars
         - DB:
         - DBDRIVER:
         - MANAGER:
     """
 
     class CrossConnection:
-        OPCUA = ("control_input")
+        OPCUA = ("control_input", "init_vars")
         CONTROLLER = ("raw_outputs", "filtered_outputs")
         AUTOENCODER = ("raw_outputs", "perturbations", "inputs")
         DB = ("raw_outputs", "filtered_outputs", "perturbations", "inputs")
